pygeodesy.namedTuples.UtmUps5Tuple

Package pygeodesy :: Module namedTuples :: Class UtmUps5Tuple |
[frames] | no frames]

# Class UtmUps5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       UtmUps5Tuple

5-Tuple `(zone, hemipole, easting, northing, band)` as `int`, `str`, `meter`, `meter` and `band` letter, where `zone` is `1..60` for UTM or `0` for UPS, `hemipole` `'N'|'S'` is the UTM hemisphere or the UPS pole and `band` is `""` or the longitudinal UTM band `'C'|'D'|..|'W'|'X'` or polar UPS band `'A'|'B'|'Y'|'Z'`.

Instance Methods
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, z, h, e, n, B, Error=None, **name) New _NamedTuple initialized with `positional` arguments. |

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, z, h, e, n, B, Error=None, **name) Static Method |
New _NamedTuple initialized with `positional` arguments. Arguments: `arg` - Tuple items (`tuple`, `list`, ...) or first tuple item of several more in other positional arguments. `args` - Tuple items (`any`), all positional arguments. `iteration_name` - Only keyword arguments `iteration=None` and `name=NN` are used, any other are silently ignored. Returns: a new object with type S, a subtype of T Raises: `LenError` - Unequal number of positional arguments and number of item `_Names_` or `_Units_`. `TypeError` - The `_Names_` or `_Units_` attribute is not a `tuple` of at least 2 items. `ValueError` - Item name is not a `str` or valid `identifier` or starts with `underscore`. Overrides: object.__new__ (inherited documentation)